==> jabber-transport-0.7.tar.gz: jabber-transport-0.7/modules/basic/auth.c <==
#include "mod_basic.h"

xmlnode mod_basic_users = NULL;

int mod_basic_auth(char *username, char *password)
{
    xmlnode next;

    if(username == NULL || password == NULL)
        return M_DEFAULT;

    jdebug(ZONE,"MOD_BASIC: user[%s] pass[%s]",username,password);

    next = xmlnode_get_firstchild(mod_basic_users);

    while(next != NULL)
    {
        if( xmlnode_get_type(next) == NTYPE_TAG && 
            j_strcmp(xmlnode_get_name(next),"user") == 0 &&
            j_strcmp(username, xmlnode_get_attrib(next, "name")) == 0)
        {
            if(j_strcmp(password, xmlnode_get_attrib(next, "pass")) == 0)
                return M_HANDLED;
            else
                return M_ERR;
        }
        next = xmlnode_get_nextsibling(next);
    }
    return M_DEFAULT;
}

int mod_basic_users_reset()
{
    jdebug(ZONE,"MOD_BASIC: users_reset");

    if(xmlnode_get_tag(mod_basic_config,"users") == NULL)
    {
        jerror("mod_basic","No User Database Configured! Please add <users>/path/to/mod_basic_users.xml</users> to the configuration.");
        return -1;
    }

    if(mod_basic_users == NULL)
        mod_basic_users = xmlnode_file(xmlnode_get_data(xmlnode_get_firstchild(xmlnode_get_tag(mod_basic_config,"users"))));
    else
        return xmlnode2file(xmlnode_get_data(xmlnode_get_firstchild(xmlnode_get_tag(mod_basic_config,"users"))),mod_basic_users);

    return 0;
}

void mod_basic_register_get(xmlnode query)
{
    jdebug(ZONE,"MOD_BASIC: register get");
    xmlnode_insert_tag(query,"username");
    xmlnode_insert_tag(query,"password");
    xmlnode_insert_tag(query,"name");
    xmlnode_insert_tag(query,"email");
}

void mod_basic_register_set(char *host, xmlnode query)
{
    char *user, *pass, *name, *email;
    xmlnode newuser;

    user = xmlnode_get_data(xmlnode_get_firstchild(xmlnode_get_tag(query,"username")));
    pass = xmlnode_get_data(xmlnode_get_firstchild(xmlnode_get_tag(query,"password")));
    name = xmlnode_get_data(xmlnode_get_firstchild(xmlnode_get_tag(query,"name")));
    email = xmlnode_get_data(xmlnode_get_firstchild(xmlnode_get_tag(query,"email")));

    if(user == NULL || pass == NULL)
    {
        xmlnode_put_attrib(xmlnode_insert_tag(query,"result"),"type","illegal");
        return;
    }

    jdebug(ZONE,"MOD_BASIC: user registration %s",user);

    if(mod_basic_check(user))
    {
        xmlnode_put_attrib(xmlnode_insert_tag(query,"result"),"type","unavailable");
        return;
    }

    newuser = xmlnode_insert_tag(mod_basic_users,"user");
    xmlnode_put_attrib(newuser,"name",user);
    xmlnode_put_attrib(newuser,"pass",pass);

    if(mod_basic_users_reset() <= 0)
    {
        xmlnode_put_attrib(xmlnode_insert_tag(query,"result"),"type","failed");
        xmlnode_hide(newuser);
        return;
    }

    xmlnode_hide(xmlnode_get_tag(query,"username"));
    xmlnode_hide(xmlnode_get_tag(query,"password"));
    mod_basic_info_set(user, query);
    xmlnode_put_attrib(xmlnode_insert_tag(query,"result"),"type","ok");    
    logger_registration(host,user);
}

void mod_basic_auth_password(char *user, xmlnode query)
{
    xmlnode newuser, next;
    char *pass;

    newuser = NULL;
    next = mod_basic_users;

    /* get the password, fail if it's null */
    pass = xmlnode_get_data(xmlnode_get_firstchild(xmlnode_get_tag(query,"password")));
    if(pass == NULL)
        next = NULL;

    while(next != NULL)
    {
        if(j_strcmp(xmlnode_get_attrib(next,"name"),user) == 0)
        {
            xmlnode_hide(next);
            newuser = xmlnode_insert_tag(mod_basic_users,"user");
            xmlnode_put_attrib(newuser,"name",user);
            xmlnode_put_attrib(newuser,"pass",pass);
            break;
        }
        next = xmlnode_get_nextsibling(next);
    }

    if(next == NULL || mod_basic_users_reset() <= 0)
    {
        xmlnode_put_attrib(xmlnode_insert_tag(query,"result"),"type","failed");
        xmlnode_hide(newuser);
        return;
    }

    xmlnode_hide(xmlnode_get_tag(query,"password"));
    xmlnode_put_attrib(xmlnode_insert_tag(query,"result"),"type","ok");    
}

==> jabber-transport-0.8.tar.gz: jabber-transport-0.8/modules/basic/auth.c <==
#include "mod_basic.h"

xmlnode mod_basic_users = NULL;

int mod_basic_auth(char *username, char *password)
{
    xmlnode next;

    if(username == NULL || password == NULL)
        return M_DEFAULT;

    jdebug(ZONE,"MOD_BASIC: user[%s] pass[%s]",username,password);

    next = xmlnode_get_firstchild(mod_basic_users);

    while(next != NULL)
    {
        if( xmlnode_get_type(next) == NTYPE_TAG && 
            j_strcmp(xmlnode_get_name(next),"user") == 0 &&
            j_strcmp(username, xmlnode_get_attrib(next, "name")) == 0)
        {
            if(j_strcmp(password, xmlnode_get_attrib(next, "pass")) == 0)
                return M_HANDLED;
            else
                return M_ERR;
        }
        next = xmlnode_get_nextsibling(next);
    }
    return M_DEFAULT;
}

int mod_basic_users_reset()
{
    jdebug(ZONE,"MOD_BASIC: users_reset");

    if(xmlnode_get_tag(mod_basic_config,"users") == NULL)
    {
        jerror("mod_basic","No User Database Configured! Please add <users>/path/to/mod_basic_users.xml</users> to the configuration.");
        return -1;
    }

    if(mod_basic_users == NULL)
        mod_basic_users = xmlnode_file(xmlnode_get_data(xmlnode_get_firstchild(xmlnode_get_tag(mod_basic_config,"users"))));
    else
        return xmlnode2file(xmlnode_get_data(xmlnode_get_firstchild(xmlnode_get_tag(mod_basic_config,"users"))),mod_basic_users);

    return 0;
}

void mod_basic_register_get(xmlnode x)
{
    xmlnode query;

    query = xmlnode_get_tag(x,"query");

    jdebug(ZONE,"MOD_BASIC: register get");
    xmlnode_insert_tag(query,"username");
    xmlnode_insert_tag(query,"password");
    xmlnode_insert_tag(query,"name");
    xmlnode_insert_tag(query,"email");
    xmlnode_put_attrib(x,"type","result");
}

void mod_basic_register_set(char *host, xmlnode x)
{
    char *user, *pass, *name, *email;
    xmlnode newuser, query;

    query = xmlnode_get_tag(x,"query");

    user = xmlnode_get_data(xmlnode_get_firstchild(xmlnode_get_tag(query,"username")));
    pass = xmlnode_get_data(xmlnode_get_firstchild(xmlnode_get_tag(query,"password")));
    xmlnode_hide(xmlnode_get_tag(query,"username"));
    xmlnode_hide(xmlnode_get_tag(query,"password"));
    name = xmlnode_get_data(xmlnode_get_firstchild(xmlnode_get_tag(query,"name")));
    email = xmlnode_get_data(xmlnode_get_firstchild(xmlnode_get_tag(query,"email")));

    if(user == NULL || pass == NULL)
    {
        js_error(x,TERROR_INVALID,"Illegal Request");
        return;
    }

    jdebug(ZONE,"MOD_BASIC: user registration %s",user);

    if(mod_basic_check(user))
    {
        js_error(x,TERROR_PROCESSING,"Username in use");
        return;
    }

    newuser = xmlnode_insert_tag(mod_basic_users,"user");
    xmlnode_put_attrib(newuser,"name",user);
    xmlnode_put_attrib(newuser,"pass",pass);

    if(mod_basic_users_reset() <= 0)
    {
        js_error(x,TERROR_PROCESSING,"Unable to save new account");
        xmlnode_hide(newuser);
        return;
    }

    mod_basic_info_set(user, query);
    xmlnode_put_attrib(x,"type","result");
    logger_registration(host,user);
}

void mod_basic_auth_password(char *user, xmlnode x)
{
    xmlnode newuser, next, query;
    char *pass;

    query = xmlnode_get_tag(x,"query");

    newuser = NULL;
    next = mod_basic_users;

    /* get the password, fail if it's null */
    pass = xmlnode_get_data(xmlnode_get_firstchild(xmlnode_get_tag(query,"password")));
    if(pass == NULL)
        next = NULL;

    while(next != NULL)
    {
        if(j_strcmp(xmlnode_get_attrib(next,"name"),user) == 0)
        {
            xmlnode_hide(next);
            newuser = xmlnode_insert_tag(mod_basic_users,"user");
            xmlnode_put_attrib(newuser,"name",user);
            xmlnode_put_attrib(newuser,"pass",pass);
            break;
        }
        next = xmlnode_get_nextsibling(next);
    }

    if(next == NULL || mod_basic_users_reset() <= 0)
    {
        js_error(x,TERROR_PROCESSING,"Unable to save change");
        xmlnode_hide(newuser);
        return;
    }

    xmlnode_hide(xmlnode_get_tag(query,"password"));
}
